==> nxcomp-1.3.2-4.tar.gz: nxcomp/OpcodeStore.cpp <==
/**************************************************************************/
/*                                                                        */
/* Copyright (c) 2001,2003 NoMachine, http://www.nomachine.com.           */
/*                                                                        */
/* NXPROXY, NX protocol compression and NX extensions to this software    */
/* are copyright of NoMachine. Redistribution and use of the present      */
/* software is allowed according to terms specified in the file LICENSE   */
/* which comes in the source distribution.                                */
/*                                                                        */
/* Check http://www.nomachine.com/licensing.html for applicability.       */
/*                                                                        */
/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
/*                                                                        */
/* All rights reserved.                                                   */
/*                                                                        */
/**************************************************************************/

#include "OpcodeStore.h"

OpcodeStore::OpcodeStore()
{
  //
  // Assign opcodes according to NX protocol.
  //

  getControlParameters = X_NXGetControlParameters;
  getCleanupParameters = X_NXGetCleanupParameters;
  getImageParameters   = X_NXGetImageParameters;
  getUnpackParameters  = X_NXGetUnpackParameters;
  getShmemParameters   = X_NXGetShmemParameters;

  startSplit  = X_NXStartSplit;
  endSplit    = X_NXEndSplit;
  split       = X_NXSplit;
  commitSplit = X_NXCommitSplit;
  abortSplit  = X_NXAbortSplit;

  sync  = X_NXSync;
  karma = X_NXKarma;

  setExposeEvents = X_NXSetExposeEvents;

  setUnpackGeometry = X_NXSetUnpackGeometry;
  setUnpackColormap = X_NXSetUnpackColormap;
  setUnpackAlpha    = X_NXSetUnpackAlpha;

  putPackedImage = X_NXPutPackedImage;

  freeUnpack = X_NXFreeUnpack;

  //
  // These must be fetched from X server.
  //

  shapeExtension  = 0;
  renderExtension = 0;

  //
  // Events sent as ClientMessage.
  //

  splitNotify = NXSplitNotify;
  syncNotify  = NXSyncNotify;
  karmaNotify = NXKarmaNotify;

  resetNotify      = NXResetNotify;
  congestionNotify = NXCongestionNotify;

  //
  // TODO: This must become a generic
  // collect notify event to be used
  // for multiple replies.
  //

  collectImageNotify = NXCollectImageNotify;
}

OpcodeStore::~OpcodeStore()
{
}

==> nxcomp-2.0.0-81.tar.gz: nxcomp/OpcodeStore.cpp <==
/**************************************************************************/
/*                                                                        */
/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
/*                                                                        */
/* NXPROXY, NX protocol compression and NX extensions to this software    */
/* are copyright of NoMachine. Redistribution and use of the present      */
/* software is allowed according to terms specified in the file LICENSE   */
/* which comes in the source distribution.                                */
/*                                                                        */
/* Check http://www.nomachine.com/licensing.html for applicability.       */
/*                                                                        */
/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
/*                                                                        */
/* All rights reserved.                                                   */
/*                                                                        */
/**************************************************************************/

#include "OpcodeStore.h"

OpcodeStore::OpcodeStore()
{
  //
  // Assign values of the specific
  // NX opcodes.
  //

  getControlParameters = X_NXGetControlParameters;
  getCleanupParameters = X_NXGetCleanupParameters;
  getImageParameters   = X_NXGetImageParameters;
  getUnpackParameters  = X_NXGetUnpackParameters;
  getShmemParameters   = X_NXGetShmemParameters;
  getFontParameters    = X_NXGetFontParameters;

  startSplit  = X_NXStartSplit;
  endSplit    = X_NXEndSplit;
  commitSplit = X_NXCommitSplit;
  finishSplit = X_NXFinishSplit;
  abortSplit  = X_NXAbortSplit;

  splitData  = X_NXSplitData;
  splitEvent = X_NXSplitEvent;

  setCacheParameters  = X_NXSetCacheParameters;
  setExposeParameters = X_NXSetExposeParameters;

  setUnpackGeometry = X_NXSetUnpackGeometry;
  setUnpackColormap = X_NXSetUnpackColormap;
  setUnpackAlpha    = X_NXSetUnpackAlpha;

  putPackedImage = X_NXPutPackedImage;

  freeUnpack = X_NXFreeUnpack;
  freeSplit  = X_NXFreeSplit;

  //
  // These values must be fetched
  // from the X server.
  //

  shapeExtension  = 0;
  renderExtension = 0;

  //
  // Events sent as ClientMessage.
  //

  resetNotify      = NXResetNotify;
  congestionNotify = NXCongestionNotify;

  noSplitNotify     = NXNoSplitNotify;
  startSplitNotify  = NXStartSplitNotify;
  commitSplitNotify = NXCommitSplitNotify;
  endSplitNotify    = NXEndSplitNotify;
  emptySplitNotify  = NXEmptySplitNotify;
}

OpcodeStore::~OpcodeStore()
{
}
